@@ -80,6 +80,17 @@ def add(ctx, section, message, modify):
         click.echo(kacl_changelog_content)
 
 
+@cli.command()
+@click.pass_context
+def current(ctx):
+    """Returns the current version from the Changelog.
+    """
+    kacl_changelog, kacl_changelog_filepath = load_changelog(ctx)
+
+    current_version = kacl_changelog.current_version()
+    click.echo(current_version)
+
+
 @cli.command()
 @click.pass_context
 @click.argument('version', type=str)
